@@ -20,8 +20,11 @@
 #ifndef ANALOGMETERWIDGET_H
 #define ANALOGMETERWIDGET_H
 
+#include <QImage>
 #include <QPainter>
 #include <QPaintEvent>
+#include <QResizeEvent>
+
 #include <volumemeterwidget.h>
 
 class AnalogMeterWidget : public VolumeMeterWidget
@@ -29,11 +32,12 @@ class AnalogMeterWidget : public VolumeMeterWidget
 public:
     AnalogMeterWidget(QWidget *parent);
 
-    void draw(QPainter *painter);
-
 protected:
-    void paintEvent(QPaintEvent *event);
+    void draw(QPainter *painter);
+    void initPainter(QPainter *painter);
 
+private:
+    void drawBackground();
 };
 
 #endif // ANALOGMETERWIDGET_H
