@@ -80,7 +80,13 @@ MainWindow::MainWindow(QWidget *parent) :
 MainWindow::~MainWindow()
 {
     delete ui;
-    context_stop();
+
+    if(volumeMeterWidget != NULL){
+        disconnect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
+        delete volumeMeterWidget;
+    }
+
+    pa_shutdown();
 }
 
 void MainWindow::changeMeter(){
