@@ -28,7 +28,7 @@ static bool availability_checked = false;
 static bool is_available = false;
 static bool finished = false;
 
-static QStringList *source_names  = NULL;
+static QStringList *source_names = NULL;
 
 void get_source_info_list_callback(pa_context *context, const pa_source_info *info, int eol, void *data){
     (void) context;
@@ -86,3 +86,12 @@ bool pa_available(){
     }
     return is_available;
 }
+
+void pa_shutdown(){
+    context_stop();
+
+    if(source_names != NULL){
+        delete source_names;
+        source_names = NULL;
+    }
+}
