@@ -25,6 +25,11 @@ VolumeLineChartWidget::VolumeLineChartWidget(QWidget *parent) : VolumeMeterWidge
     initValues();
 }
 
+VolumeLineChartWidget::~VolumeLineChartWidget(){
+    delete volumeValues;
+    volumeValues = NULL;
+}
+
 void VolumeLineChartWidget::draw(QPainter *painter){
     float vol;
 
@@ -58,12 +63,7 @@ void VolumeLineChartWidget::draw(QPainter *painter){
 }
 
 void VolumeLineChartWidget::drawBackground(){
-    if(background != NULL){
-        delete background;
-        background = NULL;
-    }
-
-    background = new QImage(size(), QImage::Format_ARGB32_Premultiplied);
+    initBackground();
 
     QPainter painter(background);
     initPainter(&painter);
